@@ -8,10 +8,11 @@
 # @Description :  有关爬虫的一些工具函数
 
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 
 import random
+from pathlib import Path
 
 from fake_useragent import UserAgent
 from gitopenlib.utils import files as gf
@@ -23,10 +24,14 @@ def update_useragent():
         ua = UserAgent()
         uas.add(ua.random)
 
-    gf.file_writer(uas, "./data/", "ua.txt", backup=False)
+    gf.file_writer(uas, "./ua/", "ua.txt", backup=False)
 
 
 def get_ua():
-    uas = gf.read_content("./data/ua.txt")
-    idx = random.randint(0, len(uas))
+    """随机获取一个 User-Agent"""
+    ua_path = "./ua/ua.txt"
+    if not Path(ua_path).exists():
+        update_useragent()
+    uas = gf.read_content(ua_path)
+    idx = random.randint(0, len(uas) - 1)
     return uas[idx]
